"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _draftJs = require("draft-js");

var _nocmsEvents = require("nocms-events");

var _draftJsExportHtml = require("draft-js-export-html");

var _draftJsImportHtml = require("draft-js-import-html");

var _linkStrategy = _interopRequireDefault(require("./helpers/linkStrategy"));

var _Link = _interopRequireDefault(require("./atoms/Link"));

var _FormattingControls = _interopRequireDefault(require("./atoms/FormattingControls"));

var _BlockStyleControls = _interopRequireDefault(require("./atoms/BlockStyleControls"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var active = function active(block, editorState) {
  var isActive;
  var selection = editorState.getSelection();
  block.findEntityRanges(function (character) {
    var entityKey = character.getEntity();
    var contentState = editorState.getCurrentContent();
    return entityKey !== null && contentState.getEntity(entityKey).getType() === 'LINK';
  }, function (start, end) {
    if (block.getKey() === selection.anchorKey && selection.anchorKey === selection.focusKey) {
      if (selection.anchorOffset >= start && selection.focusOffset <= end) {
        isActive = true;
      }
    }
  });
  return isActive;
};

var LinkEditor =
/*#__PURE__*/
function (_React$Component) {
  _inherits(LinkEditor, _React$Component);

  function LinkEditor(props) {
    var _this;

    _classCallCheck(this, LinkEditor);

    _this = _possibleConstructorReturn(this, (LinkEditor.__proto__ || Object.getPrototypeOf(LinkEditor)).call(this, props));
    Object.defineProperty(_this, "getSelectedBlockElement", {
      configurable: true,
      enumerable: true,
      writable: true,
      value: function value() {
        var selection = window.getSelection();
        if (selection.rangeCount === 0) return null;
        var node = selection.getRangeAt(0).startContainer;

        do {
          /* eslint eqeqeq: off */
          if (node.getAttribute && node.getAttribute('data-block') == 'true') {
            return node;
          }

          node = node.parentNode;
        } while (node != null);

        return null;
      }
    });
    Object.defineProperty(_this, "getSelectedClientRect", {
      configurable: true,
      enumerable: true,
      writable: true,
      value: function value() {
        var selection = window.getSelection();
        var oRange = selection.getRangeAt(0);
        return oRange.getBoundingClientRect();
      }
    });
    _this.decorator = new _draftJs.CompositeDecorator([{
      strategy: _linkStrategy.default,
      component: _Link.default
    }]);
    var convertedText = (0, _draftJsImportHtml.stateFromHTML)(props.text);
    _this.state = {
      editorState: _draftJs.EditorState.createWithContent(convertedText, _this.decorator),
      showURLInput: false,
      showToolbar: false,
      urlValue: '',
      styleObj: {},
      disableAdd: true
    };
    /* eslint react/no-string-refs: off */
    // @TODO: rewrite

    _this.focus = function () {
      return _this.refs.editor.focus();
    };

    _this.onChange = _this.onChange.bind(_this);
    _this.onBlur = _this.onBlur.bind(_this);
    _this.onFocus = _this.onFocus.bind(_this);
    _this.promptForLink = _this.promptForLink.bind(_this);

    _this.onURLChange = function (e) {
      return _this.setState({
        urlValue: e.target.value
      });
    };

    _this.confirmLink = _this.confirmLink.bind(_this);
    _this.onLinkInputKeyDown = _this.onLinkInputKeyDown.bind(_this);
    _this.handleKeyCommand = _this.handleKeyCommand.bind(_this);
    _this.toggleInlineStyle = _this.toggleInlineStyle.bind(_this);
    _this.abortLink = _this.abortLink.bind(_this);
    _this.onTab = _this.onTab.bind(_this);
    _this.toggleBlockType = _this.toggleBlockType.bind(_this);
    return _this;
  }

  _createClass(LinkEditor, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(props) {
      if (this.state.showURLInput) {
        return;
      }

      var convertedText = (0, _draftJsImportHtml.stateFromHTML)(props.text);
      this.setState({
        editorState: _draftJs.EditorState.createWithContent(convertedText, this.decorator)
      });
    }
  }, {
    key: "onLinkInputKeyDown",
    value: function onLinkInputKeyDown(e) {
      if (e.which === 13) {
        this.confirmLink(e);
      } else if (e.which === 27) {
        this.abortLink(e);
      }
    }
  }, {
    key: "onChange",
    value: function onChange(editorState) {
      var selection = editorState.getSelection();

      if (selection.isCollapsed()) {
        this.setState({
          editorState: editorState,
          disableAdd: true
        });
      } else {
        this.setState({
          editorState: editorState,
          disableAdd: false
        });
      }
    }
  }, {
    key: "onBlur",
    value: function onBlur() {
      if (this.state.showURLInput) {
        return;
      }

      var html = (0, _draftJsExportHtml.stateToHTML)(this.state.editorState.getCurrentContent());

      if (html === this.props.text) {
        return;
      }

      (0, _nocmsEvents.triggerGlobal)('nocms.value-changed', this.props.scope, html);
      this.setState({
        showToolbar: false
      });
    }
  }, {
    key: "onFocus",
    value: function onFocus() {
      this.setState({
        showToolbar: true
      });
    }
  }, {
    key: "onTab",
    value: function onTab(e) {
      var maxDepth = 4;
      this.onChange(_draftJs.RichUtils.onTab(e, this.state.editorState, maxDepth));
    }
  }, {
    key: "handleKeyCommand",
    value: function handleKeyCommand(command) {
      var newState = _draftJs.RichUtils.handleKeyCommand(this.state.editorState, command);

      if (newState) {
        this.onChange(newState);
        return true;
      }

      return false;
    }
  }, {
    key: "toggleBlockType",
    value: function toggleBlockType(blockType) {
      this.onChange(_draftJs.RichUtils.toggleBlockType(this.state.editorState, blockType));
    }
  }, {
    key: "toggleInlineStyle",
    value: function toggleInlineStyle(inlineStyle) {
      this.onChange(_draftJs.RichUtils.toggleInlineStyle(this.state.editorState, inlineStyle));
    }
  }, {
    key: "promptForLink",
    value: function promptForLink(e) {
      var _this2 = this;

      e.preventDefault();
      var editorState = this.state.editorState;
      var selection = editorState.getSelection();

      if (selection.isCollapsed()) {
        return;
      }

      var block = editorState.getCurrentContent().getBlockForKey(editorState.getSelection().getStartKey());

      if (active(block, editorState)) {
        this.setState({
          editorState: _draftJs.RichUtils.toggleLink(editorState, selection, null)
        });
      } else {
        this.setState({
          showURLInput: true,
          urlValue: ''
        }, function () {
          setTimeout(function () {
            return _this2.refs.url.focus();
          }, 0);
        });
      }
    }
  }, {
    key: "confirmLink",
    value: function confirmLink(e) {
      var _this3 = this;

      e.preventDefault();
      var _state = this.state,
          editorState = _state.editorState,
          urlValue = _state.urlValue;
      var contentState = editorState.getCurrentContent();
      var contentStateWithEntity = contentState.createEntity('LINK', 'MUTABLE', {
        url: urlValue
      });
      var entityKey = contentStateWithEntity.getLastCreatedEntityKey();

      var newEditorState = _draftJs.EditorState.set(editorState, {
        currentContent: contentStateWithEntity
      });

      this.setState({
        editorState: _draftJs.RichUtils.toggleLink(newEditorState, editorState.getSelection(), entityKey),
        showURLInput: false,
        urlValue: ''
      }, function () {
        setTimeout(function () {
          return _this3.refs.editor.focus();
        }, 0);
      });
    }
  }, {
    key: "abortLink",
    value: function abortLink(e) {
      var _this4 = this;

      e.preventDefault();
      this.setState({
        showURLInput: false,
        urlValue: ''
      }, function () {
        setTimeout(function () {
          return _this4.refs.editor.focus();
        }, 0);
      });
    }
  }, {
    key: "render",
    value: function render() {
      var urlInput;

      if (this.state.showURLInput) {
        urlInput = _react.default.createElement("div", {
          className: "text-editor__link-url"
        }, _react.default.createElement("div", null, _react.default.createElement("span", {
          className: "text-editor__link-header"
        }, "Add link"), _react.default.createElement("button", {
          className: "admin-button admin-button__icon admin-button__icon-only",
          onClick: this.abortLink
        }, _react.default.createElement("span", null, _react.default.createElement("i", {
          className: "material-icons"
        }, "close"), _react.default.createElement("span", {
          className: "sr-only"
        }, "close")))), _react.default.createElement("label", {
          htmlFor: "url"
        }, "Link"), _react.default.createElement("input", {
          id: "url",
          onChange: this.onURLChange,
          ref: "url",
          type: "text",
          value: this.state.urlValue,
          onKeyDown: this.onLinkInputKeyDown
        }), _react.default.createElement("div", {
          className: "admin-button-container"
        }, _react.default.createElement("button", {
          className: "admin-button",
          onClick: this.confirmLink
        }, "OK")));
      }

      return _react.default.createElement("div", {
        className: "text-editor",
        ref: "textEditor"
      }, _react.default.createElement("div", {
        className: "text-editor__controls",
        style: {
          visibility: this.state.showToolbar ? 'visible' : 'hidden'
        }
      }, _react.default.createElement(_FormattingControls.default, {
        editorState: this.state.editorState,
        onToggle: this.toggleInlineStyle
      }), _react.default.createElement(_BlockStyleControls.default, {
        editorState: this.state.editorState,
        onToggle: this.toggleBlockType
      }), _react.default.createElement("button", {
        onMouseDown: this.promptForLink,
        className: "admin-button admin-button_icon formatting-button ".concat(this.state.disableAdd ? 'formatting-button--disabled' : null)
      }, _react.default.createElement("i", {
        className: "material-icons"
      }, "insert_link"))), _react.default.createElement("div", {
        className: "text-editor__body"
      }, urlInput, _react.default.createElement(_draftJs.Editor, {
        editorState: this.state.editorState,
        onChange: this.onChange,
        handleKeyCommand: this.handleKeyCommand,
        onBlur: this.onBlur,
        onFocus: this.onFocus,
        onTab: this.onTab,
        placeholder: this.props.placeholder,
        ref: "editor",
        autoComplete: "off"
      })));
    }
  }]);

  return LinkEditor;
}(_react.default.Component);

LinkEditor.propTypes = {
  text: _propTypes.default.string,
  placeholder: _propTypes.default.string,
  scope: _propTypes.default.string
};
LinkEditor.defaultProps = {
  text: ''
};
var _default = LinkEditor;
exports.default = _default;
//# sourceMappingURL=LinkEditor.js.map